=========
ChangeLog
=========

2.0.0
=====

* Ported to GitHub
* Converted to use genemail_ and TemplateAlchemy_
* Renamed "genshi-compile" engine to "genshic"
* Refactored CLI option loading


.. _genemail: https://pypi.python.org/pypi/genemail
.. _TemplateAlchemy: https://pypi.python.org/pypi/TemplateAlchemy
